Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: net/quic/quic_crypto_stream.cc

Issue 14083012: QUIC: retransmit packets with the correct encryption. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Moved HandshakeMode enum to MockCryptoClientStream Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/quic/quic_crypto_stream.cc
diff --git a/net/quic/quic_crypto_stream.cc b/net/quic/quic_crypto_stream.cc
index 9167e6f78ca099bb5773067488d069bd643a801a..df6c610813ba1a43ac2e68e0a4ef882ea184f9cc 100644
--- a/net/quic/quic_crypto_stream.cc
+++ b/net/quic/quic_crypto_stream.cc
@@ -18,7 +18,8 @@ namespace net {
QuicCryptoStream::QuicCryptoStream(QuicSession* session)
: ReliableQuicStream(kCryptoStreamId, session),
- handshake_complete_(false) {
+ encryption_established_(false),
+ handshake_confirmed_(false) {
crypto_framer_.set_visitor(this);
}
@@ -28,8 +29,8 @@ void QuicCryptoStream::OnError(CryptoFramer* framer) {
uint32 QuicCryptoStream::ProcessData(const char* data,
uint32 data_len) {
- // Do not process handshake messages after the handshake is complete.
- if (handshake_complete()) {
+ // Do not process handshake messages after the handshake is confirmed.
+ if (handshake_confirmed()) {
CloseConnection(QUIC_CRYPTO_MESSAGE_AFTER_HANDSHAKE_COMPLETE);
return 0;
}
@@ -49,11 +50,6 @@ void QuicCryptoStream::CloseConnectionWithDetails(QuicErrorCode error,
session()->connection()->SendConnectionCloseWithDetails(error, details);
}
-void QuicCryptoStream::SetHandshakeComplete(QuicErrorCode error) {
- handshake_complete_ = true;
- session()->OnCryptoHandshakeComplete(error);
-}
-
void QuicCryptoStream::SendHandshakeMessage(
const CryptoHandshakeMessage& message) {
const QuicData& data = message.GetSerialized();

Powered by Google App Engine
This is Rietveld 408576698